@@ -5,11 +5,13 @@ require 'mechanize'
 require 'logger'
 
 # Create a new mechanize object
-agent = Mechanize.new { |a| a.log = Logger.new(STDERR) }
+mech = Mechanize.new
+mech.log = Logger.new $stderr
+mech.agent.http.debug_output = $stderr
 
 # Load the rubyforge website
-page = agent.get('http://rubyforge.org/')
-page = agent.click page.link_with(:text => /Log In/) # Click the login link
+page = mech.get('http://rubyforge.org/')
+page = mech.click page.link_with(:text => /Log In/) # Click the login link
 form = page.forms[1] # Select the first form
 form.form_loginname = ARGV[0]
 form.form_pw        = ARGV[1]
