@@ -73,7 +73,7 @@ class Mechanize
   ##
   # The version of Mechanize you are using.
 
-  VERSION = '2.7.2'
+  VERSION = '2.7.3'
 
   ##
   # Base mechanize error class
@@ -169,9 +169,17 @@ class Mechanize
   #     a.proxy_host = 'proxy.example'
   #     a.proxy_port = 8080
   #   end
+  #
+  # If you need segregated SSL connections give each agent a unique
+  # name.  Otherwise the connections will be shared.  This is
+  # particularly important if you are using certifcates.
+  #
+  #    agent_1 = Mechanize.new 'conn1'
+  #    agent_2 = Mechanize.new 'conn2'
+  #
 
-  def initialize
-    @agent = Mechanize::HTTP::Agent.new
+  def initialize(connection_name = 'mechanize')
+    @agent = Mechanize::HTTP::Agent.new(connection_name)
     @agent.context = self
     @log = nil
 
@@ -1285,6 +1293,7 @@ Use of #auth and #basic_auth are deprecated due to a security vulnerability.
 
 end
 
+require 'mechanize/element_not_found_error'
 require 'mechanize/response_read_error'
 require 'mechanize/chunked_termination_error'
 require 'mechanize/content_type_error'
