@@ -4,6 +4,7 @@
 
 class Mechanize::Form::RadioButton < Mechanize::Form::Field
   attr_accessor :checked
+  attr_reader :form
 
   def initialize node, form
     @checked = !!node['checked']
@@ -11,6 +12,15 @@ class Mechanize::Form::RadioButton < Mechanize::Form::Field
     super(node)
   end
 
+  def == other # :nodoc:
+    self.class === other and
+      other.form  == @form and
+      other.name  == @name and
+      other.value == @value
+  end
+
+  alias eql? == # :nodoc:
+
   def check
     uncheck_peers
     @checked = true
@@ -26,6 +36,10 @@ class Mechanize::Form::RadioButton < Mechanize::Form::Field
     checked ? uncheck : check
   end
 
+  def hash # :nodoc:
+    @form.hash ^ @name.hash ^ @value.hash
+  end
+
   def label
     (id = self['id']) && @form.page.labels_hash[id] || nil
   end
