@@ -1,6 +1,6 @@
 class Mechanize::HTTP
 
-  AuthChallenge = Struct.new :scheme, :params
+  AuthChallenge = Struct.new :scheme, :params, :raw
 
   ##
   # A parsed WWW-Authenticate header
@@ -18,7 +18,10 @@ class Mechanize::HTTP
     # The authentication parameters
 
     ##
-    # :method: initialize(scheme = nil, params = nil)
+    # :method: initialize
+    #
+    # :call-seq:
+    #   initialize(scheme = nil, params = nil)
     #
     # Creates a new AuthChallenge header with the given scheme and parameters
 
@@ -45,14 +48,17 @@ class Mechanize::HTTP
     end
 
     ##
-    # The reconstructed, normalized challenge
+    # The name of the realm for this challenge
 
-    def to_s
-      auth_params = params.map { |name, value| "#{name}=\"#{value}\"" }
-
-      "#{scheme} #{auth_params.join ', '}"
+    def realm_name
+      params['realm'] if Hash === params # NTLM has a string for params
     end
 
+    ##
+    # The raw authentication challenge
+
+    alias to_s raw
+
   end
 
 end
