@@ -25,6 +25,7 @@ class Mechanize::HTTP::WWWAuthenticateParser
 
     while true do
       break if @scanner.eos?
+      start = @scanner.pos
       challenge = Mechanize::HTTP::AuthChallenge.new
 
       scheme = auth_scheme
@@ -43,8 +44,11 @@ class Mechanize::HTTP::WWWAuthenticateParser
           challenge.params = @scanner.scan(/.*/)
         end
 
+        challenge.raw = www_authenticate[start, @scanner.pos]
         challenges << challenge
         next
+      else
+        scheme.capitalize!
       end
 
       next unless space
@@ -55,13 +59,20 @@ class Mechanize::HTTP::WWWAuthenticateParser
         pos = @scanner.pos
         name, value = auth_param
 
+        name.downcase! if name =~ /^realm$/i
+
         unless name then
           challenge.params = params
           challenges << challenge
-          break if @scanner.eos?
+
+          if @scanner.eos? then
+            challenge.raw = www_authenticate[start, @scanner.pos]
+            break
+          end
 
           @scanner.pos = pos # rewind
-          challenge = '' # a token should be next, new challenge
+          challenge.raw = www_authenticate[start, @scanner.pos].sub(/(,+)? *$/, '')
+          challenge = nil # a token should be next, new challenge
           break
         else
           params[name] = value
@@ -69,8 +80,6 @@ class Mechanize::HTTP::WWWAuthenticateParser
 
         spaces
 
-        return nil unless ',' == @scanner.peek(1) or @scanner.eos?
-
         @scanner.scan(/(, *)+/)
       end
     end
