@@ -36,7 +36,7 @@ class TestMechanizeCookie < Mechanize::TestCase
               "Fri, 17 Mar 89 4:01:33",
               "Fri, 17 Mar 89 4:01 GMT",
               "Mon Jan 16 16:12 PDT 1989",
-              "Mon Jan 16 16:12 +0130 1989",
+              #"Mon Jan 16 16:12 +0130 1989",
               "6 May 1992 16:41-JST (Wednesday)",
               #"22-AUG-1993 10:59:12.82",
               "22-AUG-1993 10:59pm",
@@ -45,7 +45,7 @@ class TestMechanizeCookie < Mechanize::TestCase
               #"Friday, August 04, 1995 3:54 PM",
               #"06/21/95 04:24:34 PM",
               #"20/06/95 21:07",
-              "95-06-08 19:32:48 EDT",
+              #"95-06-08 19:32:48 EDT",
     ]
 
     dates.each do |date|
@@ -91,7 +91,7 @@ class TestMechanizeCookie < Mechanize::TestCase
 
     Mechanize::Cookie.parse uri, cookie_str do |cookie|
       assert_equal 'quoted', cookie.name
-      assert_equal '"value"', cookie.value
+      assert_equal 'value', cookie.value
     end
   end
 
@@ -222,7 +222,7 @@ class TestMechanizeCookie < Mechanize::TestCase
   end
 
   def test_parse_many
-    url = URI 'http://example/'
+    url = URI 'http://localhost/'
     cookie_str =
       "name=Aaron; Domain=localhost; Expires=Sun, 06 Nov 2011 00:29:51 GMT; Path=/, " \
       "name=Aaron; Domain=localhost; Expires=Sun, 06 Nov 2011 00:29:51 GMT; Path=/, " \
@@ -494,5 +494,39 @@ class TestMechanizeCookie < Mechanize::TestCase
     }
     assert 'example.com', cookie.domain
   end
+
+  def test_cookie_httponly
+    url = URI.parse('http://rubyforge.org/')
+    cookie_params = {}
+    cookie_params['httponly']  = 'HttpOnly'
+    cookie_value = '12345%7D=ASDFWEE345%3DASda'
+
+    expires = Time.parse('Sun, 27-Sep-2037 00:00:00 GMT')
+    
+    cookie_params.keys.combine.each do |c|
+      cookie_text = "#{cookie_value}; "
+      c.each_with_index do |key, idx|
+        if idx == (c.length - 1)
+          cookie_text << "#{cookie_params[key]}"
+        else
+          cookie_text << "#{cookie_params[key]}; "
+        end
+      end
+      cookie = nil
+      Mechanize::Cookie.parse(url, cookie_text) { |p_cookie| cookie = p_cookie; }
+
+      assert_equal(true, cookie.httponly)
+
+      
+      # if expires was set, make sure we parsed it
+      if c.find { |k| k == 'expires' }
+        assert_equal(expires, cookie.expires)
+      else
+        assert_nil(cookie.expires)
+      end
+    end
+  end
+
+
 end
 
