@@ -25,9 +25,24 @@ class TestMechanizeDownload < Mechanize::TestCase
     download = @parser.new uri, nil, body_io
 
     in_tmpdir do
-      download.save
+      filename = download.save
 
       assert File.exist? 'foo.html'
+      assert_equal "foo.html", filename
+    end
+  end
+
+  def test_save_bang
+    uri = URI.parse 'http://example/foo.html'
+    body_io = StringIO.new '0123456789'
+
+    download = @parser.new uri, nil, body_io
+
+    in_tmpdir do
+      filename = download.save!
+
+      assert File.exist? 'foo.html'
+      assert_equal "foo.html", filename
     end
   end
 
@@ -43,9 +58,20 @@ class TestMechanizeDownload < Mechanize::TestCase
       download = @parser.new uri, nil, body_io
 
       in_tmpdir do
-        download.save
+        filename = download.save
 
         assert File.exist? 'foo.html'
+        assert_equal "foo.html", filename
+
+        filename = download.save
+
+        assert File.exist? 'foo.html.1'
+        assert_equal "foo.html.1", filename
+
+        filename = download.save
+
+        assert File.exist? 'foo.html.2'
+        assert_equal "foo.html.2", filename
       end
     end
   end
