@@ -33,6 +33,11 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
     realm
   end
 
+  def test_agent_is_named
+    assert_equal 'mechanize', Mechanize::HTTP::Agent.new.http.name
+    assert_equal 'unique', Mechanize::HTTP::Agent.new('unique').http.name
+  end
+
   def test_auto_io
     Tempfile.open 'input' do |input_io|
       input_io.binmode
@@ -1584,6 +1589,11 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
     assert_equal 'invalid value for port: "nonexistent service"', e.message
   end
 
+  def test_setting_agent_name
+    mech = Mechanize.new 'user-set-name'
+    assert_equal 'user-set-name', mech.agent.http.name
+  end
+
   def test_ssl
     in_tmpdir do
       store = OpenSSL::X509::Store.new
